@@ -24,9 +24,13 @@ import android.app.Notification;
 import android.app.NotificationManager;
 import android.app.PendingIntent;
 import android.app.Service;
+import android.bluetooth.BluetoothDevice;
+import android.bluetooth.BluetoothClass;
+import android.content.BroadcastReceiver;
 import android.content.ComponentName;
 import android.content.Context;
 import android.content.Intent;
+import android.content.IntentFilter;
 import android.content.ServiceConnection;
 import android.os.Build;
 import android.os.IBinder;
@@ -55,6 +59,7 @@ public class Main extends Service implements Runnable {
 	private String mError = null;
 	private final RemoteCallbackList<IMainCallback> mCallbacks = new RemoteCallbackList<IMainCallback>();
 	private final IBinder mBinder = new MainStub(this);
+	private boolean mPauseOnHeadphonesDisconnect = false;
 	private PowerManager.WakeLock mWakelock = null;
 
 	static class MainStub extends IMain.Stub {
@@ -68,6 +73,9 @@ public class Main extends Service implements Runnable {
 		public void stop() {
 			mService.stop();
 		}
+		public void setPauseOnHeadphonesDisconnect(boolean enabled) {
+			mService.setPauseOnHeadphonesDisconnect(enabled);
+		}
 		public void setWakelockEnabled(boolean enabled) {
 			mService.setWakelockEnabled(enabled);
 		}
@@ -191,6 +199,28 @@ public class Main extends Service implements Runnable {
 		if (mThread != null)
 			return;
 
+		IntentFilter filter = new IntentFilter();
+		filter.addAction(Intent.ACTION_HEADSET_PLUG);
+		filter.addAction(BluetoothDevice.ACTION_ACL_DISCONNECT_REQUESTED);
+		filter.addAction(BluetoothDevice.ACTION_ACL_DISCONNECTED);
+		registerReceiver(new BroadcastReceiver() {
+			@Override
+			public void onReceive(Context context, Intent intent) {
+				if (!mPauseOnHeadphonesDisconnect) {
+					return;
+				}
+
+				if (intent.getAction().equals(Intent.ACTION_HEADSET_PLUG)) {
+					if (intent.hasExtra("state") && intent.getIntExtra("state", 0) == 0)
+						pause();
+				} else {
+					BluetoothDevice device = intent.getParcelableExtra(BluetoothDevice.EXTRA_DEVICE);
+					if (device.getBluetoothClass().hasService(BluetoothClass.Service.AUDIO))
+						pause();
+				}
+			}
+		}, filter);
+
 		final Intent mainIntent = new Intent(this, Settings.class);
 		mainIntent.setAction("android.intent.action.MAIN");
 		mainIntent.addCategory("android.intent.category.LAUNCHER");
@@ -241,6 +271,21 @@ public class Main extends Service implements Runnable {
 		stopSelf();
 	}
 
+	private void pause() {
+		if (mThread != null) {
+			if (mThread.isAlive()) {
+				synchronized (this) {
+					if (mStatus == MAIN_STATUS_STARTED)
+						Bridge.pause();
+				}
+			}
+		}
+	}
+
+	private void setPauseOnHeadphonesDisconnect(boolean enabled) {
+		mPauseOnHeadphonesDisconnect = enabled;
+	}
+
 	private void setWakelockEnabled(boolean enabled) {
 		if (enabled && mWakelock == null) {
 			PowerManager pm = (PowerManager)getSystemService(Context.POWER_SERVICE);
@@ -368,6 +413,19 @@ public class Main extends Service implements Runnable {
 			}
 		}
 
+		public boolean setPauseOnHeadphonesDisconnect(boolean enabled) {
+			synchronized (this) {
+				if (mIMain != null) {
+					try {
+						mIMain.setPauseOnHeadphonesDisconnect(enabled);
+						return true;
+					} catch (RemoteException e) {
+					}
+				}
+				return false;
+			}
+		}
+
 		public boolean setWakelockEnabled(boolean enabled) {
 			synchronized (this) {
 				if (mIMain != null) {
@@ -414,6 +472,15 @@ public class Main extends Service implements Runnable {
 	 * start Main service without any callback
 	 */
 	public static void start(Context context, boolean wakelock) {
-		context.startService(new Intent(context, Main.class).putExtra("wakelock", wakelock));
+		Intent intent = new Intent(context, Main.class)
+			.putExtra("wakelock", wakelock);
+
+		if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O)
+			/* in Android 8+, we need to use this method
+			   or else we'll get "IllegalStateException:
+			   app is in background" */
+			context.startForegroundService(intent);
+		else
+			context.startService(intent);
 	}
 }
