@@ -142,14 +142,24 @@ struct Config {
 #ifdef ENABLE_DAEMON
 
 static void
-glue_daemonize_init(const struct options *options,
+glue_daemonize_init(const CommandLineOptions &options,
 		    const ConfigData &config)
 {
+	auto pid_file = config.GetPath(ConfigOption::PID_FILE);
+
+#ifdef __linux__
+	if (options.systemd && pid_file != nullptr) {
+		pid_file = nullptr;
+		fprintf(stderr,
+			"Ignoring the 'pid_file' setting in systemd mode\n");
+	}
+#endif
+
 	daemonize_init(config.GetString(ConfigOption::USER),
 		       config.GetString(ConfigOption::GROUP),
-		       config.GetPath(ConfigOption::PID_FILE));
+		       std::move(pid_file));
 
-	if (options->kill)
+	if (options.kill)
 		daemonize_kill();
 }
 
@@ -361,7 +371,8 @@ Instance::BeginShutdownPartitions() noexcept
 }
 
 static inline void
-MainConfigured(const struct options &options, const ConfigData &raw_config)
+MainConfigured(const CommandLineOptions &options,
+	       const ConfigData &raw_config)
 {
 #ifdef ENABLE_DAEMON
 	daemonize_close_stdin();
@@ -384,7 +395,7 @@ MainConfigured(const struct options &options, const ConfigData &raw_config)
 	const Config config(raw_config);
 
 #ifdef ENABLE_DAEMON
-	glue_daemonize_init(&options, raw_config);
+	glue_daemonize_init(options, raw_config);
 #endif
 
 	TagLoadConfig(raw_config);
@@ -582,7 +593,7 @@ MainConfigured(const struct options &options, const ConfigData &raw_config)
 static void
 AndroidMain()
 {
-	struct options options;
+	CommandLineOptions options;
 	ConfigData raw_config;
 
 	const auto sdcard = Environment::getExternalStorageDirectory();
@@ -642,7 +653,7 @@ Java_org_musicpd_Bridge_pause(JNIEnv *, jclass)
 static inline void
 MainOrThrow(int argc, char *argv[])
 {
-	struct options options;
+	CommandLineOptions options;
 	ConfigData raw_config;
 
 	ParseCommandLine(argc, argv, options, raw_config);
