@@ -52,29 +52,24 @@ AddUri(Client &client, const LocatedUri &uri)
 				      SongLoader(client).LoadSong(uri));
 }
 
-static CommandResult
-AddDatabaseSelection(Client &client, const char *uri,
-		     [[maybe_unused]] Response &r)
-{
 #ifdef ENABLE_DATABASE
-	auto &partition = client.GetPartition();
+
+static void
+AddDatabaseSelection(Partition &partition, const char *uri)
+{
 	const ScopeBulkEdit bulk_edit(partition);
 
 	const DatabaseSelection selection(uri, true);
 	AddFromDatabase(partition, selection);
-	return CommandResult::OK;
-#else
-	(void)client;
-	(void)uri;
-
-	r.Error(ACK_ERROR_NO_EXIST, "No database");
-	return CommandResult::ERROR;
-#endif
 }
 
+#endif
+
 CommandResult
-handle_add(Client &client, Request args, Response &r)
+handle_add(Client &client, Request args, [[maybe_unused]] Response &r)
 {
+	auto &partition = client.GetPartition();
+
 	const char *uri = args.front();
 	if (StringIsEqual(uri, "/"))
 		/* this URI is malformed, but some clients are buggy
@@ -84,6 +79,11 @@ handle_add(Client &client, Request args, Response &r)
 		   here */
 		uri = "";
 
+	const auto old_size = partition.playlist.GetLength();
+	const unsigned position = args.size > 1
+		? ParseInsertPosition(args[1], partition.playlist)
+		: old_size;
+
 	const auto located_uri = LocateUri(UriPluginKind::INPUT, uri,
 					   &client
 #ifdef ENABLE_DATABASE
@@ -94,18 +94,34 @@ handle_add(Client &client, Request args, Response &r)
 	case LocatedUri::Type::ABSOLUTE:
 		AddUri(client, located_uri);
 		client.GetInstance().LookupRemoteTag(located_uri.canonical_uri);
-		return CommandResult::OK;
+		break;
 
 	case LocatedUri::Type::PATH:
 		AddUri(client, located_uri);
-		return CommandResult::OK;
+		break;
 
 	case LocatedUri::Type::RELATIVE:
-		return AddDatabaseSelection(client, located_uri.canonical_uri,
-					    r);
+#ifdef ENABLE_DATABASE
+		AddDatabaseSelection(partition, located_uri.canonical_uri);
+		break;
+#else
+		r.Error(ACK_ERROR_NO_EXIST, "No database");
+		return CommandResult::ERROR;
+#endif
 	}
 
-	gcc_unreachable();
+	if (position < old_size) {
+		const unsigned new_size = partition.playlist.GetLength();
+		const RangeArg move_range{old_size, new_size};
+
+		try {
+			partition.MoveRange(move_range, position);
+		} catch (...) {
+			/* ignore - shall we handle it? */
+		}
+	}
+
+	return CommandResult::OK;
 }
 
 CommandResult
