@@ -36,7 +36,7 @@ UpdateRemoveService::RunDeferred() noexcept
 	std::forward_list<std::string> copy;
 
 	{
-		const std::lock_guard<Mutex> protect(mutex);
+		const std::scoped_lock<Mutex> protect(mutex);
 		std::swap(uris, copy);
 	}
 
@@ -55,7 +55,7 @@ UpdateRemoveService::Remove(std::string &&uri)
 	bool was_empty;
 
 	{
-		const std::lock_guard<Mutex> protect(mutex);
+		const std::scoped_lock<Mutex> protect(mutex);
 		was_empty = uris.empty();
 		uris.emplace_front(std::move(uri));
 	}
