@@ -38,7 +38,7 @@
 #include "tag/Builder.hxx"
 #include "tag/Handler.hxx"
 #include "tag/ReplayGain.hxx"
-#include "tag/MixRamp.hxx"
+#include "tag/MixRampParser.hxx"
 #include "input/InputStream.hxx"
 #include "pcm/CheckAudioFormat.hxx"
 #include "util/ScopeExit.hxx"
