@@ -40,7 +40,7 @@ CurlGlobal *CurlInit::instance;
 
 CurlInit::CurlInit(EventLoop &event_loop)
 {
-	const std::lock_guard<Mutex> protect(mutex);
+	const std::scoped_lock<Mutex> protect(mutex);
 	if (++ref > 1) {
 		assert(&event_loop == &instance->GetEventLoop());
 		return;
@@ -56,7 +56,7 @@ CurlInit::CurlInit(EventLoop &event_loop)
 
 CurlInit::~CurlInit() noexcept
 {
-	const std::lock_guard<Mutex> protect(mutex);
+	const std::scoped_lock<Mutex> protect(mutex);
 	if (--ref > 0)
 		return;
 
