@@ -1,5 +1,5 @@
 /*
- * Copyright 2003-2020 The Music Player Daemon Project
+ * Copyright 2003-2021 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,7 +26,7 @@
 
 #include <string.h>
 
-const NeighborPlugin *const neighbor_plugins[] = {
+constexpr const NeighborPlugin *neighbor_plugins[] = {
 #ifdef ENABLE_SMBCLIENT
 	&smbclient_neighbor_plugin,
 #endif
