@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2019 Max Kellermann <max.kellermann@gmail.com>
+ * Copyright 2012-2020 Max Kellermann <max.kellermann@gmail.com>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -31,15 +31,9 @@
 
 #include <cassert>
 
-static const struct sockaddr_in *
-CastToIPv4(const struct sockaddr *p) noexcept
-{
-	assert(p->sa_family == AF_INET);
-
-	/* cast through void to work around the bogus alignment warning */
-	const void *q = reinterpret_cast<const void *>(p);
-	return reinterpret_cast<const struct sockaddr_in *>(q);
-}
-
 IPv4Address::IPv4Address(SocketAddress src) noexcept
-	:address(*CastToIPv4(src.GetAddress())) {}
+	:address(src.CastTo<struct sockaddr_in>())
+{
+	assert(!src.IsNull());
+	assert(src.GetFamily() == AF_INET);
+}
