@@ -71,9 +71,9 @@ pcm_resample_lsr_global_init(const ConfigBlock &block)
 		throw FormatRuntimeError("unknown samplerate converter '%s'",
 					 converter);
 
-	FormatDebug(libsamplerate_domain,
-		    "libsamplerate converter '%s'",
-		    src_get_name(lsr_converter));
+	FmtDebug(libsamplerate_domain,
+		 "libsamplerate converter '{}'",
+		 src_get_name(lsr_converter));
 }
 
 AudioFormat
@@ -98,9 +98,9 @@ LibsampleratePcmResampler::Open(AudioFormat &af, unsigned new_sample_rate)
 	memset(&data, 0, sizeof(data));
 
 	data.src_ratio = double(new_sample_rate) / double(af.sample_rate);
-	FormatDebug(libsamplerate_domain,
-		    "setting samplerate conversion ratio to %.2lf",
-		    data.src_ratio);
+	FmtDebug(libsamplerate_domain,
+		 "setting samplerate conversion ratio to {:.2}",
+		 data.src_ratio);
 	src_set_ratio(state, data.src_ratio);
 
 	AudioFormat result = af;
