@@ -23,7 +23,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-AllocatedString<>
+AllocatedString
 FormatStringV(const char *fmt, std::va_list args) noexcept
 {
 	std::va_list tmp;
@@ -37,10 +37,10 @@ FormatStringV(const char *fmt, std::va_list args) noexcept
 
 	char *buffer = new char[length + 1];
 	vsnprintf(buffer, length + 1, fmt, args);
-	return AllocatedString<>::Donate(buffer);
+	return AllocatedString::Donate(buffer);
 }
 
-AllocatedString<>
+AllocatedString
 FormatString(const char *fmt, ...) noexcept
 {
 	std::va_list args;
