@@ -164,6 +164,8 @@ static int
 dump_input_stream(InputStream &is, FileDescriptor out,
 		  offset_type seek, size_t chunk_size)
 {
+	out.SetBinaryMode();
+
 	std::unique_lock<Mutex> lock(is.mutex);
 
 	if (seek > 0)
@@ -221,14 +223,14 @@ public:
 
 	/* virtual methods from RemoteTagHandler */
 	void OnRemoteTag(Tag &&_tag) noexcept override {
-		const std::lock_guard<Mutex> lock(mutex);
+		const std::scoped_lock<Mutex> lock(mutex);
 		tag = std::move(_tag);
 		done = true;
 		cond.notify_all();
 	}
 
 	void OnRemoteTagError(std::exception_ptr e) noexcept override {
-		const std::lock_guard<Mutex> lock(mutex);
+		const std::scoped_lock<Mutex> lock(mutex);
 		error = std::move(e);
 		done = true;
 		cond.notify_all();
